@@ -36,8 +36,8 @@ from global_chem.medicinal_chemistry.rings.phase_2_hetereocyclic_rings import Ph
 
 # Medicinal Chemistry - Scaffolds
 
+from global_chem.medicinal_chemistry.scaffolds.iupac_blue_book import IUPACBlueBook
 from global_chem.medicinal_chemistry.scaffolds.privileged_scaffolds import PrivilegedScaffolds
-from global_chem.medicinal_chemistry.scaffolds.iupac_blue_book_substituents import IUPACBlueBook
 from global_chem.medicinal_chemistry.scaffolds.common_r_group_replacements import CommonRGroupReplacements
 
 # Proteins Kinases
@@ -327,7 +327,7 @@ class GlobalChem(object):
         'montmorillonite_adsorption': MontmorilloniteAdsorption,                 # Asuka Orr & Suliman Sharif
         'common_monomer_repeating_units': CommonMonomerRepeatingUnits,           # Suliman Sharif
         'electrophilic_warheads_for_kinases': ElectrophilicWarheadsForKinases,   # Ruibin Liu & Suliman Sharif
-        'common_warhead_covalent_inhibitors': CommonWarheadsCovalentInhibitors,  # Shaoqi Zhao & Suliman Sharif
+        'common_warheads_covalent_inhibitors': CommonWarheadsCovalentInhibitors,  # Shaoqi Zhao & Suliman Sharif
         'rings_in_drugs': RingsInDrugs,                                          # Alexander Mackerell & Suliman Sharif
         'iupac_blue_book_rings': IUPACBlueBookRings,                             # Suliman Sharif
         'phase_2_hetereocyclic_rings': Phase2HetereoCyclicRings,                 # Suliman Sharif
